@@ -31,7 +31,7 @@
 
 class EncoderFLACConfig : public QWidget, public Ui::EncoderFLACConfig {
 public:
-  explicit EncoderFLACConfig(QWidget *parent = 0) : QWidget( parent ) { setupUi( this ); }
+  explicit EncoderFLACConfig(QWidget *parent = nullptr) : QWidget( parent ) { setupUi( this ); }
 };
 
 /**
@@ -45,11 +45,11 @@ public:
   explicit EncoderFLAC(KIO::SlaveBase *slave);
   ~EncoderFLAC();
 
-  virtual QString type() const override { return QLatin1String( "FLAC" ); };
+  virtual QString type() const override { return QLatin1String( "FLAC" ); }
   virtual bool init() override;
   virtual void loadSettings() override;
   virtual unsigned long size(long time_secs) const override;
-  virtual const char * fileType() const override { return "flac"; };
+  virtual const char * fileType() const override { return "flac"; }
   virtual const char * mimeType() const override { return "audio/x-flac"; }
   virtual void fillSongInfo( KCDDB::CDInfo info, int track, const QString &comment ) override;
   virtual long readInit(long size) override;
