@@ -27,7 +27,7 @@
 class EncoderLameConfig : public QWidget, public Ui::EncoderLameConfig
 {
 public:
-  EncoderLameConfig( QWidget *parent = 0 ) : QWidget( parent ) {
+  EncoderLameConfig( QWidget *parent = nullptr ) : QWidget( parent ) {
     setupUi( this );
   }
 };
@@ -35,7 +35,7 @@ public:
 
 /**
  * MP3 encoder using the LAME encoder.
- * Go to http://lame.sourceforge.net/ for lots of information.
+ * Go to https://lame.sourceforge.io/ for more information.
  */ 
 class EncoderLame : public QObject, public AudioCDEncoder {
 
